@@ -1,13 +1,15 @@
 package Algorithm::Backoff::MILD;
 
-our $DATE = '2019-06-20'; # DATE
-our $VERSION = '0.009'; # VERSION
-
 use strict;
 use warnings;
 
 use parent qw(Algorithm::Backoff);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-02-24'; # DATE
+our $DIST = 'Algorithm-Backoff'; # DIST
+our $VERSION = '0.010'; # VERSION
+
 our %SPEC;
 
 $SPEC{new} = {
@@ -70,7 +72,7 @@ Algorithm::Backoff::MILD - Multiplicative Increment, Linear Decrement (MILD) bac
 
 =head1 VERSION
 
-This document describes version 0.009 of Algorithm::Backoff::MILD (from Perl distribution Algorithm-Backoff), released on 2019-06-20.
+This document describes version 0.010 of Algorithm::Backoff::MILD (from Perl distribution Algorithm-Backoff), released on 2024-02-24.
 
 =head1 SYNOPSIS
 
@@ -226,6 +228,7 @@ Maximum delay time, in seconds.
 
 Maximum delay time, in seconds.
 
+
 =back
 
 Return value:  (obj)
@@ -238,14 +241,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Algorithm-
 
 Source repository is at L<https://github.com/perlancar/perl-Algorithm-Backoff>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Algorithm-Backoff>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Algorithm::Backoff::LILD>
@@ -262,11 +257,37 @@ Other C<Algorithm::Backoff::*> classes.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by perlancar@cpan.org.
+This software is copyright (c) 2024, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Algorithm-Backoff>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
